@@ -11,16 +11,6 @@ from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import open_file
 from pyaedt.generic.general_methods import pyaedt_function_handler
-from pyaedt.modeler.advanced_cad.stackup_3d import Stackup3D
-from pyaedt.modeler.modeler2d import Modeler2D
-from pyaedt.modeler.modeler3d import Modeler3D
-from pyaedt.modules.Mesh import Mesh
-from pyaedt.modules.MeshIcepak import IcepakMesh
-
-if is_ironpython:
-    from pyaedt.modules.PostProcessor import PostProcessor
-else:
-    from pyaedt.modules.AdvancedPostProcessing import PostProcessor
 
 
 class FieldAnalysis3D(Analysis, object):
@@ -101,9 +91,9 @@ class FieldAnalysis3D(Analysis, object):
             port,
             aedt_process_id,
         )
-        self._modeler = Modeler2D(self) if application in ["Maxwell 2D", "2D Extractor"] else Modeler3D(self)
-        self._mesh = IcepakMesh(self) if application == "Icepak" else Mesh(self)
-        self._post = PostProcessor(self)
+        self._post = None
+        self._modeler = None
+        self._mesh = None
         self._configurations = Configurations(self)
 
     @property
@@ -123,7 +113,14 @@ class FieldAnalysis3D(Analysis, object):
         Returns
         -------
         :class:`pyaedt.modeler.modeler3d.Modeler3D` or :class:`pyaedt.modeler.modeler2d.Modeler2D`
+            Modeler object.
         """
+        if self._modeler is None:
+            from pyaedt.modeler.modeler2d import Modeler2D
+            from pyaedt.modeler.modeler3d import Modeler3D
+
+            self._modeler = Modeler2D(self) if self.design_type in ["Maxwell 2D", "2D Extractor"] else Modeler3D(self)
+
         return self._modeler
 
     @property
@@ -133,9 +130,32 @@ class FieldAnalysis3D(Analysis, object):
         Returns
         -------
         :class:`pyaedt.modules.Mesh.Mesh` or :class:`pyaedt.modules.MeshIcepak.IcepakMesh`
+            Mesh object.
         """
+        if self._mesh is None:
+            from pyaedt.modules.Mesh import Mesh
+            from pyaedt.modules.MeshIcepak import IcepakMesh
+
+            self._mesh = IcepakMesh(self) if self.design_type == "Icepak" else Mesh(self)
         return self._mesh
 
+    @property
+    def post(self):
+        """PostProcessor.
+
+        Returns
+        -------
+        :class:`pyaedt.modules.AdvancedPostProcessing.PostProcessor`
+            PostProcessor object.
+        """
+        if self._post is None:
+            if is_ironpython:  # pragma: no cover
+                from pyaedt.modules.PostProcessor import PostProcessor
+            else:
+                from pyaedt.modules.AdvancedPostProcessing import PostProcessor
+            self._post = PostProcessor(self)
+        return self._post
+
     @property
     def components3d(self):
         """3D components.
@@ -163,7 +183,6 @@ class FieldAnalysis3D(Analysis, object):
                     for file in files:
                         if file.endswith(".a3dcomp"):
                             listfiles.append(os.path.join(root, file))
-                # listfiles = glob.glob(syspath + "/**/*.a3dcomp", recursive=True)
                 for el in listfiles:
                     head, tail = ntpath.split(el)
                     components_dict[tail[:-8]] = el
@@ -180,6 +199,7 @@ class FieldAnalysis3D(Analysis, object):
         force_opacity_value=None,
         clean_files=False,
         view="isometric",
+        show_legend=True,
     ):
         """Plot the model or a subset of objects.
 
@@ -208,6 +228,8 @@ class FieldAnalysis3D(Analysis, object):
         view : str, optional
            View to export. Options are ``"isometric"``, ``"xy"``, ``"xz"``, ``"yz"``.
            The default is ``"isometric"``.
+        show_legend : bool, optional
+            Whether to display the legend or not. The default is ``True``.
 
         Returns
         -------
@@ -228,6 +250,7 @@ class FieldAnalysis3D(Analysis, object):
                 force_opacity_value=force_opacity_value,
                 clean_files=clean_files,
                 view=view,
+                show_legend=show_legend,
             )
 
     @pyaedt_function_handler()
@@ -726,12 +749,14 @@ class FieldAnalysis3D(Analysis, object):
         """
         if len(self.modeler.objects) != len(self.modeler.object_names):
             self.modeler.refresh_all_ids()
-        cond = self.materials.conductors
         obj_names = []
-        for mat in cond:
-            obj_names.extend(self.modeler.get_objects_by_material(mat))
-            obj_names.extend(self.modeler.get_objects_by_material(self.materials[mat].name))
-        return list(set(obj_names))
+        for _, val in self.modeler.objects.items():
+            try:
+                if val.material_name and self.materials[val.material_name].is_conductor():
+                    obj_names.append(val.name)
+            except KeyError:
+                pass
+        return obj_names
 
     @pyaedt_function_handler()
     def get_all_dielectrics_names(self):
@@ -750,10 +775,13 @@ class FieldAnalysis3D(Analysis, object):
             self.modeler.refresh_all_ids()
         diel = self.materials.dielectrics
         obj_names = []
-        for mat in diel:
-            obj_names.extend(self.modeler.get_objects_by_material(mat))
-            obj_names.extend(self.modeler.get_objects_by_material(self.materials[mat].name))
-        return list(set(obj_names))
+        for _, val in self.modeler.objects.items():
+            try:
+                if val.material_name and self.materials[val.material_name].is_dielectric():
+                    obj_names.append(val.name)
+            except KeyError:
+                pass
+        return obj_names
 
     @pyaedt_function_handler()
     def _create_dataset_from_sherlock(self, material_string, property_name="Mass_Density"):
@@ -925,6 +953,8 @@ class FieldAnalysis3D(Analysis, object):
         :class:`pyaedt.modeler.stackup_3d.Stackup3D`
             Stackup class.
         """
+        from pyaedt.modeler.advanced_cad.stackup_3d import Stackup3D
+
         return Stackup3D(self)
 
     @pyaedt_function_handler()
@@ -947,7 +977,7 @@ class FieldAnalysis3D(Analysis, object):
         bool
             `True` if succeeded.
         """
-        native_comp_names = [i.props["BasicComponentInfo"]["ComponentName"] for _, i in self.native_components.items()]
+        native_comp_names = [nc.component_name for _, nc in self.native_components.items()]
         if not component_name:
             component_name = [
                 key
@@ -959,31 +989,54 @@ class FieldAnalysis3D(Analysis, object):
                 component_name = [component_name]
             for cmp in component_name:
                 assert cmp in self.modeler.user_defined_component_names, "Component Definition not found."
+
         for cmp in component_name:
             comp = self.modeler.user_defined_components[cmp]
+            target_cs = self.modeler._create_reference_cs_from_3dcomp(comp, password=password)
             app = comp.edit_definition(password=password)
             for var, val in comp.parameters.items():
                 app[var] = val
             if purge_history:
                 app.modeler.purge_history(app.modeler._all_object_names)
-            self.modeler.set_working_coordinate_system(comp.target_coordinate_system)
+            monitor_cache = {}
             if self.design_type == "Icepak":
                 objs_monitors = [part.name for _, part in comp.parts.items()]
-                monitor_cache = {}
                 for mon_name, mon_obj in self.monitor.all_monitors.items():
                     obj_name = mon_obj.properties["Geometry Assignment"]
                     if obj_name in objs_monitors:
                         monitor_cache.update({mon_obj.name: mon_obj.properties})
+                        monitor_cache[mon_obj.name]["Native Assignment"] = "placeholder"
+                        if monitor_cache[mon_obj.name]["Type"] == "Face":
+                            monitor_cache[mon_obj.name]["Area Assignment"] = self.modeler.get_face_area(
+                                monitor_cache[mon_obj.name]["ID"]
+                            )
+                        elif monitor_cache[mon_obj.name]["Type"] == "Surface":
+                            monitor_cache[mon_obj.name]["Area Assignment"] = self.modeler.get_face_area(
+                                self.modeler.get_object_from_name(monitor_cache[mon_obj.name]["ID"]).faces[0].id
+                            )
+                        elif monitor_cache[mon_obj.name]["Type"] == "Object":
+                            monitor_cache[mon_obj.name]["Volume Assignment"] = self.modeler.get_object_from_name(
+                                monitor_cache[mon_obj.name]["ID"]
+                            ).volume
+                for _, mon_dict in monitor_cache.items():
+                    del mon_dict["Object"]
             oldcs = self.oeditor.GetActiveCoordinateSystem()
-            self.modeler.set_working_coordinate_system(
-                self.modeler.user_defined_components[cmp].target_coordinate_system
-            )
+            self.modeler.set_working_coordinate_system(target_cs)
             comp.delete()
+            obj_set = set(self.modeler.objects.values())
             self.copy_solid_bodies_from(app, no_vacuum=False, no_pec=False, include_sheets=True)
+            self.modeler.refresh_all_ids()
             self.modeler.set_working_coordinate_system(oldcs)
             if self.design_type == "Icepak":
-                for _, mon_dict in monitor_cache.items():
-                    self.monitor.insert_monitor_object_from_dict(mon_dict, mode=1)
-            app.close_project(save_project=False)
-            self.modeler.refresh_all_ids()
+                for monitor_obj, mon_dict in monitor_cache.items():
+                    if not self.monitor.insert_monitor_object_from_dict(mon_dict, mode=1):
+                        dict_in = {"monitor": {monitor_obj: mon_dict}}
+                        self.configurations._monitor_assignment_finder(dict_in, monitor_obj, obj_set)
+                        m_type = dict_in["monitor"][monitor_obj]["Type"]
+                        m_obj = dict_in["monitor"][monitor_obj]["ID"]
+                        if not self.configurations.update_monitor(
+                            m_type, m_obj, dict_in["monitor"][monitor_obj]["Quantity"], monitor_obj
+                        ):  # pragma: no cover
+                            return False
+            app.oproject.Close()
         return True
