@@ -366,9 +366,6 @@ class Components(object):
     def Others(self):
         """Other core components.
 
-        Parameters
-        ----------
-
         Returns
         -------
         dict[str, :class:`pyaedt.edb_core.edb_data.components_data.EDBComponent`]
@@ -794,31 +791,31 @@ class Components(object):
                 for net in net_list:
                     pins = [pin for pin in cmp_pins if pin.GetNet().GetName() == net]
                     if pins:
-                        pin_group = self.create_pingroup_from_pins(pins)
-                        if not pin_group:
-                            return False
-                        pin_group_term = self._create_pin_group_terminal(pin_group, component)
-                        if pin_group_term:
-                            pin_group_term.SetReferenceTerminal(ref_pin_group_term)
+                        if len(pins) == 1:
+                            pin_term = self._create_terminal(pins[0])
+                            if pin_term:
+                                pin_term.SetReferenceTerminal(ref_pin_group_term)
+                        else:
+                            pin_group = self.create_pingroup_from_pins(pins)
+                            if not pin_group:
+                                return False
+                            pin_group_term = self._create_pin_group_terminal(pin_group, component)
+                            if pin_group_term:
+                                pin_group_term.SetReferenceTerminal(ref_pin_group_term)
                     else:
                         self._logger.info("No pins found on component {} for the net {}".format(component, net))
-
             else:
                 ref_pin_group = self.create_pingroup_from_pins(ref_pins)
                 if not ref_pin_group:
                     self._logger.warning("failed to create reference pin group")
                     return False
+                ref_pin_group_term = self._create_pin_group_terminal(ref_pin_group, component, isref=True)
                 for net in net_list:
                     pins = [pin for pin in cmp_pins if pin.GetNet().GetName() == net]
                     for pin in pins:
-                        ref_pin = self._get_closest_pin_from(pin, ref_pins)
-                        ref_pin_term = self._create_terminal(ref_pin)
-                        term = self._create_terminal(pin)
-                        ref_pin_term.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
-                        ref_pin_term.SetIsCircuitPort(True)
-                        term.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
-                        term.SetIsCircuitPort(True)
-                        term.SetReferenceTerminal(ref_pin_term)
+                        pin_group = self.create_pingroup_from_pins([pin])
+                        pin_group_term = self._create_pin_group_terminal(pin_group, component, isref=False)
+                        pin_group_term.SetReferenceTerminal(ref_pin_group_term)
         return True
 
     @pyaedt_function_handler()
@@ -842,7 +839,7 @@ class Components(object):
         cmp_name = pin.GetComponent().GetName()
         net_name = pin.GetNet().GetName()
         pin_name = pin.GetName()
-        term_name = "{}.{}.{}".format(cmp_name, net_name, pin_name)
+        term_name = "{}.{}.{}".format(cmp_name, pin_name, net_name)
         term = self._edb.Cell.Terminal.PointTerminal.Create(
             pin.GetLayout(), pin.GetNet(), term_name, pin_pos, from_layer
         )
@@ -1005,9 +1002,9 @@ class Components(object):
         net_name = pingroup.GetNet().GetName()
         pin_name = list(pingroup.GetPins())[0].GetName()  # taking first pin name as convention.
         if cmp_name:
-            term_name = "{0}.{1}.{2}".format(net_name, cmp_name, pin_name)
+            term_name = "{0}.{1}.{2}".format(cmp_name, pin_name, net_name)
         else:
-            term_name = "{0}.{1}".format(net_name, pin_name)
+            term_name = "{0}.{1}".format(pin_name, net_name)
         pingroup_term = self._edb.Cell.Terminal.PinGroupTerminal.Create(
             self._active_layout, pingroup.GetNet(), term_name, pingroup, isref
         )
@@ -1260,7 +1257,6 @@ class Components(object):
                 return False
 
         elif model_type == "Touchstone":  # pragma: no cover
-
             nPortModelName = modelname
             edbComponentDef = edbComponent.GetComponentDef()
             nPortModel = self._edb.Definition.NPortComponentModel.FindByName(edbComponentDef, nPortModelName)
@@ -2050,11 +2046,9 @@ class Components(object):
         """
         through_comp_list = []
         for refdes, comp_obj in self.resistors.items():
-
             numpins = comp_obj.numpins
 
             if numpins == 2:
-
                 value = comp_obj.res_value
                 value = resistor_value_parser(value)
 
