@@ -266,6 +266,10 @@ class Material(object):
     @pyaedt_function_handler()
     def _json_format(self):
         out_dict = {}
+        if self.permittivity == 0:  # pragma no cover
+            self.permittivity = 1.0
+        if self.permeability == 0:  # pragma no cover
+            self.permeability = 1.0
         self._name = self.name
         self._conductivity = self.conductivity
         self._loss_tangent = self.loss_tangent
@@ -372,6 +376,27 @@ class Materials(object):
         dielectric_loss_tangent=0,
         magnetic_loss_tangent=0,
     ):
+        """Add a new material.
+
+        Parameters
+        ----------
+        name : str, optional
+            Material Name. The default is ``"air"``.
+        permittivity : float, str, optional
+            Material permittivity. The default is ``1.0006``.
+        permeability : float, str, optional
+            Material permeability. The default is ``1.0000004``.
+        conductivity : float, str, optional
+            Material conductivity. The default is ``0``.
+        dielectric_loss_tangent : float, str, optional
+            Material dielectric loss tangent. The default is ``0``.
+        magnetic_loss_tangent : float, str, optional
+            Material magnetic loss tangent. The default is ``0``.
+
+        Returns
+        -------
+        :class:`pyaedt.edb_core.materials.Material`
+        """
         if not name in self.materials:
             self._edb.Definition.MaterialDef.Create(self._db, name)
             new_material = self.materials[name]
@@ -395,7 +420,10 @@ class Materials(object):
             Name of the new material.
         conductivity : float
             Conductivity of the new material.
+
+        Returns
         -------
+        :class:`pyaedt.edb_core.materials.Material`
 
         """
         if not name in self.materials:
@@ -423,9 +451,10 @@ class Materials(object):
             Loss tangent of the new material.
         permeability: float
             Permeability of the new material.
+
         Returns
         -------
-
+        :class:`pyaedt.edb_core.materials.Material`
         """
         if not name in self.materials:
             self._edb.Definition.MaterialDef.Create(self._db, name)
@@ -440,11 +469,11 @@ class Materials(object):
 
     @pyaedt_function_handler()
     def get_djordjevicsarkar_model(self, material_name=None):
-        """
+        """Djordjevic-Sarkar model if present.
 
         Parameters
         ----------
-        material_name
+        material_name : str
 
         Returns
         -------
@@ -477,7 +506,7 @@ class Materials(object):
 
         Returns
         -------
-        type
+        :class:`pyaedt.edb_core.materials.Material`
             Material definition.
         """
         material_def = self._edb.Definition.DjordjecvicSarkarModel()
@@ -527,7 +556,7 @@ class Materials(object):
 
         Returns
         -------
-        type
+        :class:`pyaedt.edb_core.materials.Material`
             Material definition.
         """
         material_def = self._edb.Definition.DebyeModel()
@@ -561,7 +590,7 @@ class Materials(object):
 
         Returns
         -------
-        type
+        :class:`pyaedt.edb_core.materials.Material`
             Material definition.
 
         Examples
@@ -655,13 +684,23 @@ class Materials(object):
 
     @pyaedt_function_handler()
     def _load_materials(self, material=None):
-        if material:
-            if not material["name"] in self.materials:
-                if material["conductivity"] > 1e4:
-                    self.add_conductor_material(material["name"], material["conductivity"])
-                else:
-                    self.add_dielectric_material(material["name"], material["permittivity"], material["loss_tangent"])
+        if self.materials:
+            mat_keys = [i.lower() for i in self.materials.keys()]
+            mat_keys_case = [i for i in self.materials.keys()]
+        else:
+            mat_keys = []
+            mat_keys_case = []
+
+        if not material:
+            return
+        if material["name"].lower() not in mat_keys:
+            if material["conductivity"] > 1e4:
+                self.add_conductor_material(material["name"], material["conductivity"])
+            else:
+                self.add_dielectric_material(material["name"], material["permittivity"], material["loss_tangent"])
             self.materials[material["name"]]._load(material)
+        else:
+            self.materials[mat_keys_case[mat_keys.index(material["name"].lower())]]._load(material)
 
     @pyaedt_function_handler
     def material_name_to_id(self, property_name):
@@ -717,7 +756,7 @@ class Materials(object):
         Returns
         -------
         float
-            the float value of the property.
+            The float value of the property.
 
 
         Examples
