@@ -4,15 +4,22 @@ import os
 from collections import OrderedDict
 from datetime import datetime
 
+from pyaedt import Icepak
 from pyaedt import __version__
+from pyaedt import generate_unique_folder_name
+from pyaedt import get_pyaedt_app
+from pyaedt.application.Variables import decompose_variable_value
 from pyaedt.generic.DataHandlers import _arg2dict
 from pyaedt.generic.general_methods import _create_json_file
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import pyaedt_function_handler
+from pyaedt.generic.LoadAEDTFile import load_keyword_in_aedt_file
+from pyaedt.modeler.cad.components_3d import UserDefinedComponent
 from pyaedt.modeler.cad.Modeler import CoordinateSystem
 from pyaedt.modeler.geometry_operators import GeometryOperators
 from pyaedt.modules.Boundary import BoundaryObject
 from pyaedt.modules.Boundary import BoundaryProps
+from pyaedt.modules.Boundary import NativeComponentObject
 from pyaedt.modules.DesignXPloration import SetupOpti
 from pyaedt.modules.DesignXPloration import SetupParam
 from pyaedt.modules.MaterialLib import Material
@@ -889,7 +896,11 @@ class Configurations(object):
                     setup_el.props = props
                     setup_el.update()
                 return True
-        if self._app.create_setup(name, props["SetupType"], props):
+        if self._app.design_type == "Q3D Extractor":
+            setup = self._app.create_setup(name, props=props)
+        else:
+            setup = self._app.create_setup(name, setuptype=props["SetupType"], props=props)
+        if setup:
             self._app.logger.info("Setup {} added.".format(name))
             return True
         else:
@@ -950,7 +961,7 @@ class Configurations(object):
             )
 
     @pyaedt_function_handler()
-    def import_config(self, config_file):
+    def import_config(self, config_file, *args):
         """Import configuration settings from a json file and apply it to the current design.
         The sections to be applied are defined with ``configuration.options`` class.
         The import operation result is saved in the ``configuration.results`` class.
@@ -965,6 +976,8 @@ class Configurations(object):
         dict, bool
             Config dictionary.
         """
+        if len(args) > 0:  # pragma: no cover
+            raise TypeError("import_config expected at most 1 arguments, got %d" % (len(args) + 1))
         self.results._reset_results()
         with open(config_file) as json_file:
             dict_in = json.load(json_file)
@@ -1027,13 +1040,13 @@ class Configurations(object):
                 newmat = Material(self._app, el, val)
                 if newmat.update():
                     self._app.materials.material_keys[newname] = newmat
-                else:
+                else:  # pragma: no cover
                     self.results.import_materials = False
 
         if self.options.import_coordinate_systems and dict_in.get("coordinatesystems", None):
             self.results.import_coordinate_systems = True
             for name, props in dict_in["coordinatesystems"].items():
-                if not self._update_coordinate_systems(name, props):
+                if not self._update_coordinate_systems(name, props):  # pragma: no cover
                     self.results.import_coordinate_systems = False
 
         # if self.options.import_face_coordinate_systems and dict_in.get("facecoordinatesystems", None):
@@ -1183,6 +1196,10 @@ class Configurations(object):
             dict_out["objects"][val.name]["Color"] = val.color
             dict_out["objects"][val.name]["CoordinateSystem"] = val.part_coordinate_system
 
+    @pyaedt_function_handler()
+    def _export_object_properties(self, dict_out):
+        self._export_objects_properties(dict_out)
+
     @pyaedt_function_handler()
     def _export_mesh_operations(self, dict_out):
         if self._app.mesh.meshoperations:
@@ -1213,6 +1230,12 @@ class Configurations(object):
     @pyaedt_function_handler()
     def _export_monitor(self, dict_out):
         dict_monitor = {}
+        native_parts = [
+            part.name
+            for udc_name, udc in self._app.modeler.user_defined_components.items()
+            for part_name, part in udc.parts.items()
+            if self._app.modeler.user_defined_components[udc_name].definition_name in self._app.native_components
+        ]
         if self._app.monitor.all_monitors != {}:
             for mon_name in self._app.monitor.all_monitors:
                 dict_monitor[mon_name] = {
@@ -1220,6 +1243,27 @@ class Configurations(object):
                     for key, val in self._app.monitor.all_monitors[mon_name].properties.items()
                     if key not in ["Name", "Object"]
                 }
+                if dict_monitor[mon_name]["Geometry Assignment"] in native_parts:
+                    dict_monitor[mon_name]["Native Assignment"] = [
+                        name
+                        for name, dict_comp in self._app.modeler.user_defined_components.items()
+                        if dict_monitor[mon_name]["Geometry Assignment"]
+                        in [part.name for part_id, part in dict_comp.parts.items()]
+                    ][0]
+                    if dict_monitor[mon_name]["Type"] == "Face":
+                        dict_monitor[mon_name]["Area Assignment"] = self._app.modeler.get_face_area(
+                            dict_monitor[mon_name]["ID"]
+                        )
+                    elif dict_monitor[mon_name]["Type"] == "Surface":
+                        dict_monitor[mon_name]["Area Assignment"] = self._app.modeler.get_face_area(
+                            self._app.modeler.get_object_from_name(dict_monitor[mon_name]["ID"]).faces[0].id
+                        )
+                    elif dict_monitor[mon_name]["Type"] == "Object":
+                        bb = self._app.modeler.get_object_from_name([dict_monitor[mon_name]["ID"]][0]).bounding_box
+                        dict_monitor[mon_name]["Location"] = [(bb[i] + bb[i + 3]) / 2 for i in range(3)]
+                        dict_monitor[mon_name]["Volume Assignment"] = self._app.modeler.get_object_from_name(
+                            dict_monitor[mon_name]["ID"]
+                        ).volume
         dict_out["monitor"] = dict_monitor
 
     @pyaedt_function_handler()
@@ -1280,31 +1324,10 @@ class Configurations(object):
             )
         dict_out = {}
         self._export_general(dict_out)
-        if self.options.export_variables:
-            self._export_variables(dict_out)
-        if self.options.export_setups:
-            self._export_setups(dict_out)
-        if self.options.export_optimizations:
-            self._export_optimizations(dict_out)
-        if self.options.export_parametrics:
-            self._export_parametrics(dict_out)
-        if self.options.export_boundaries:
-            self._export_boundaries(dict_out)
-        if self.options.export_coordinate_systems:
-            self._export_coordinate_systems(dict_out)
-        # if self.options.export_face_coordinate_systems:
-        #     self._export_face_coordinate_systems(dict_out)
-        if self.options.export_object_properties:
-            self._export_objects_properties(dict_out)
-        if self.options.export_mesh_operations:
-            self._export_mesh_operations(dict_out)
-        if self.options.export_materials:
-            self._export_materials(dict_out)
-        if self.options.export_datasets:
-            self._export_datasets(dict_out)
-        if hasattr(self.options, "export_monitor"):
-            if self.options.export_monitor:
-                self._export_monitor(dict_out)
+        for key, value in vars(self.options).items():
+            if key.startswith("_export_") and value:
+                getattr(self, key)(dict_out)
+
         # update the json if it exists already
 
         if os.path.exists(config_file) and not overwrite:
@@ -1337,6 +1360,8 @@ class ConfigurationsOptionsIcepak(ConfigurationsOptions):
         ConfigurationsOptions.__init__(self)
         self._export_monitor = True
         self._import_monitor = True
+        self._export_native_components = True
+        self._import_native_components = True
 
     @property
     def import_monitor(self):
@@ -1354,6 +1379,22 @@ class ConfigurationsOptionsIcepak(ConfigurationsOptions):
     def export_monitor(self, val):
         self._export_monitor = val
 
+    @property
+    def import_native_components(self):
+        return self._import_native_components
+
+    @import_native_components.setter
+    def import_native_components(self, val):
+        self._import_native_components = val
+
+    @property
+    def export_native_components(self):
+        return self._export_native_components
+
+    @export_native_components.setter
+    def export_native_components(self, val):
+        self._export_native_components = val
+
 
 class ConfigurationsIcepak(Configurations):
     """Configuration Class.
@@ -1373,13 +1414,22 @@ class ConfigurationsIcepak(Configurations):
                 arg2.append(["NAME:Material", "Value:=", chr(34) + val["Material"] + chr(34)])
             if val.get("SolveInside", None):
                 arg2.append(["NAME:Solve Inside", "Value:=", val["SolveInside"]])
-            arg2.append(
-                [
-                    "NAME:Surface Material",
-                    "Value:=",
-                    chr(34) + val.get("SurfaceMaterial", "Steel-oxidised-surface") + chr(34),
-                ]
-            )
+            try:
+                arg2.append(
+                    [
+                        "NAME:Surface Material",
+                        "Value:=",
+                        chr(34) + val.get("SurfaceMaterial") + chr(34),
+                    ]
+                )
+            except TypeError:
+                arg2.append(
+                    [
+                        "NAME:Surface Material",
+                        "Value:=",
+                        chr(34) + "Steel-oxidised-surface" + chr(34),
+                    ]
+                )
             if val.get("Model", None):
                 arg2.append(["NAME:Model", "Value:=", val["Model"]])
             if val.get("Group", None):
@@ -1430,7 +1480,13 @@ class ConfigurationsIcepak(Configurations):
     @pyaedt_function_handler()
     def _export_objects_properties(self, dict_out):
         dict_out["objects"] = {}
+        udc_parts_id = []
+        if hasattr(self._app.modeler, "user_defined_components"):
+            self._app.modeler.refresh_all_ids()
+            udc_parts_id = [part for _, uc in self._app.modeler.user_defined_components.items() for part in uc.parts]
         for val in self._app.modeler.objects.values():
+            if val.id in udc_parts_id:
+                continue
             dict_out["objects"][val.name] = {}
             dict_out["objects"][val.name]["SurfaceMaterial"] = val.surface_material_name
             dict_out["objects"][val.name]["Material"] = val.material_name
@@ -1501,15 +1557,378 @@ class ConfigurationsIcepak(Configurations):
         return True
 
     @pyaedt_function_handler()
-    def import_config(self, config_file):
+    def _monitor_assignment_finder(self, dict_in, monitor_obj, exclude_set):
+        if dict_in["monitor"][monitor_obj].get("Native Assignment", None):
+            objects_to_check = [obj for _, obj in self._app.modeler.objects.items()]
+            objects_to_check = list(set(objects_to_check) - exclude_set)
+            if dict_in["monitor"][monitor_obj]["Type"] == "Face":
+                for obj in objects_to_check:
+                    for f in obj.faces:
+                        if (
+                            GeometryOperators.v_norm(
+                                GeometryOperators.v_sub(f.center, dict_in["monitor"][monitor_obj]["Location"])
+                            )
+                            <= 1e-12
+                            and abs(f.area - dict_in["monitor"][monitor_obj]["Area Assignment"]) <= 1e-12
+                        ):
+                            dict_in["monitor"][monitor_obj]["ID"] = f.id
+                            return
+            elif dict_in["monitor"][monitor_obj]["Type"] == "Surface":
+                for obj in objects_to_check:
+                    if len(obj.faces) == 1:
+                        for f in obj.faces:
+                            if (
+                                GeometryOperators.v_norm(
+                                    GeometryOperators.v_sub(f.center, dict_in["monitor"][monitor_obj]["Location"])
+                                )
+                                <= 1e-12
+                                and abs(f.area - dict_in["monitor"][monitor_obj]["Area Assignment"]) <= 1e-12
+                            ):
+                                dict_in["monitor"][monitor_obj]["ID"] = obj.name
+                                return
+            elif dict_in["monitor"][monitor_obj]["Type"] == "Object":
+                for obj in objects_to_check:
+                    bb = obj.bounding_box
+                    if (
+                        GeometryOperators.v_norm(
+                            GeometryOperators.v_sub(
+                                [(bb[i] + bb[i + 3]) / 2 for i in range(3)], dict_in["monitor"][monitor_obj]["Location"]
+                            )
+                        )
+                        <= 1e-12
+                        and abs(obj.volume - dict_in["monitor"][monitor_obj]["Volume Assignment"]) <= 1e-12
+                    ):
+                        dict_in["monitor"][monitor_obj]["ID"] = obj.id
+                        return
+            elif dict_in["monitor"][monitor_obj]["Type"] == "Vertex":
+                for obj in objects_to_check:
+                    for v in obj.vertices:
+                        if (
+                            GeometryOperators.v_norm(
+                                GeometryOperators.v_sub(v.position, dict_in["monitor"][monitor_obj]["Location"])
+                            )
+                            <= 1e-12
+                        ):
+                            dict_in["monitor"][monitor_obj]["ID"] = v.id
+                            return
+
+    @pyaedt_function_handler()
+    def import_config(self, config_file, *args):
+        """Import configuration settings from a json file and apply it to the current design.
+        The sections to be applied are defined with ``configuration.options`` class.
+        The import operation result is saved in the ``configuration.results`` class.
+
+        Parameters
+        ----------
+        config_file : str
+            Full path to json file.
+        *args : set, optional
+            Name of objects to ignore for monitor assignment.
+
+        Returns
+        -------
+        dict, bool
+            Config dictionary.
+        """
+        if len(args) == 0:
+            exclude_set = set()
+        elif len(args) == 1:
+            exclude_set = args[0]
+        else:  # pragma: no cover
+            raise TypeError("import_config expected at most 2 arguments, got %d" % (len(args) + 1))
+        with open(config_file) as json_file:
+            dict_in = json.load(json_file)
+        self.results._reset_results()
+
+        if self.options.import_native_components and dict_in.get("native components", None):
+            result_coordinate_systems = True
+            add_cs = list(dict_in["coordinatesystems"].keys())
+            available_cs = ["Global"] + [cs.name for cs in self._app.modeler.coordinate_systems]
+            i = 0
+            while add_cs:
+                if dict_in["coordinatesystems"][add_cs[i]]["Reference CS"] in available_cs:
+                    if not self._update_coordinate_systems(
+                        add_cs[i], dict_in["coordinatesystems"][add_cs[i]]
+                    ):  # pragma: no cover
+                        result_coordinate_systems = False
+                    available_cs.append(add_cs[i])
+                    add_cs.pop(i)
+                    i = 0
+                else:
+                    i += 1
+            self.options.import_coordinate_systems = False
+            result_native_component = True
+            for component_name, component_dict in dict_in["native components"].items():
+                if not self._update_native_components(component_name, component_dict):  # pragma: no cover
+                    result_native_component = False
+
         dict_in = Configurations.import_config(self, config_file)
         if self.options.import_monitor and dict_in.get("monitor", None):
             self.results.import_monitor = True
             for monitor_obj in dict_in["monitor"]:
+                self._monitor_assignment_finder(dict_in, monitor_obj, exclude_set)
                 m_type = dict_in["monitor"][monitor_obj]["Type"]
                 m_obj = dict_in["monitor"][monitor_obj]["ID"]
                 if m_type == "Point":
                     m_obj = dict_in["monitor"][monitor_obj]["Location"]
-                if not self.update_monitor(m_type, m_obj, dict_in["monitor"][monitor_obj]["Quantity"], monitor_obj):
+                if not self.update_monitor(
+                    m_type, m_obj, dict_in["monitor"][monitor_obj]["Quantity"], monitor_obj
+                ):  # pragma: no cover
                     self.results.import_monitor = False
+        try:
+            self.results.import_native_components = result_native_component
+            self.results.import_coordinate_systems = result_coordinate_systems
+        except UnboundLocalError:
+            pass
         return dict_in
+
+    @pyaedt_function_handler
+    def _get_duplicate_names(self):
+        # Copy project to get dictionary
+        directory = os.path.join(
+            self._app.toolkit_directory,
+            self._app.design_name,
+            generate_unique_folder_name("config_export_temp_project"),
+        )
+        os.makedirs(directory)
+        tempproj_name = os.path.join(directory, "temp_proj.aedt")
+        tempproj = Icepak(tempproj_name, specified_version=self._app._aedt_version)
+        empty_design = tempproj.design_list[0]
+        self._app.modeler.refresh()
+        self._app.modeler.delete(
+            list(
+                set([id for id, obj in self._app.modeler.objects.items() if obj.model])
+                - set([id for _, obj in self._app.modeler.user_defined_components.items() for id in obj.parts])
+            )
+        )
+        self._app.oproject.CopyDesign(self._app.design_name)
+        self._app.odesign.Undo()
+        tempproj.oproject.Paste()
+        tempproj.modeler.refresh_all_ids()
+        tempproj.delete_design(empty_design)
+        tempproj.close_project()
+        dictionary = load_keyword_in_aedt_file(tempproj_name, "UserDefinedModels")["UserDefinedModels"]
+        for root, dirs, files in os.walk(directory, topdown=False):
+            for name in files:
+                os.remove(os.path.join(root, name))
+            for name in dirs:
+                os.rmdir(os.path.join(root, name))
+        os.rmdir(directory)
+        operation_dict = {"Source": {}, "Duplicate": {}}
+        list_dictionaries = []
+        for key in ["NativeComponentInstanceWithParams", "NativeComponentInstance", "UserDefinedModel"]:
+            if dictionary.get(key, None):
+                if not isinstance(dictionary[key], list):
+                    list_dictionaries.append(dictionary[key])
+                else:
+                    list_dictionaries += dictionary[key]
+        for component in list_dictionaries:
+            obj_name = component["Attributes"]["Name"]
+            counter_line, counter_axis, counter_mirror = 0, 0, 0
+            if component["Operations"].get("UDMOperation", None):
+                udm_operations = component["Operations"]["UDMOperation"]
+                if not isinstance(udm_operations, list):
+                    udm_operations = [udm_operations]
+                for operation in udm_operations:
+                    if operation["OperationType"].startswith("UDMFromDup"):
+                        if operation["CloneOperId"] in operation_dict["Duplicate"]:
+                            operation_dict["Duplicate"][operation["CloneOperId"]].append(obj_name)
+                        else:
+                            operation_dict["Duplicate"][operation["CloneOperId"]] = [obj_name]
+            if component["Operations"].get("CloneToOperation", None):
+                clone_operations = component["Operations"]["CloneToOperation"]
+                if not isinstance(clone_operations, list):
+                    clone_operations = [clone_operations]
+                for operation in clone_operations:
+                    if operation["OperationType"] == "UDMDuplicateAlongLine":
+                        counter_line += 1
+                        operation_dict["Source"][operation["ID"]] = [
+                            "DuplicateAlongLine:" + str(counter_line),
+                            obj_name,
+                        ]
+                    elif operation["OperationType"] == "UDMDuplicateAroundAxis":
+                        counter_axis += 1
+                        operation_dict["Source"][operation["ID"]] = [
+                            "DuplicateAroundAxis:" + str(counter_axis),
+                            obj_name,
+                        ]
+                    elif operation["OperationType"] == "UDMDuplicateMirror":
+                        counter_mirror += 1
+                        operation_dict["Source"][operation["ID"]] = ["DuplicateMirror:" + str(counter_mirror), obj_name]
+        duplicate_dict = {}
+        for operation_id, prop in operation_dict["Source"].items():
+            if not duplicate_dict.get(prop[1], None):
+                duplicate_dict[prop[1]] = {}
+            duplicate_dict[prop[1]][prop[0]] = operation_dict["Duplicate"][operation_id]
+        return duplicate_dict
+
+    @pyaedt_function_handler
+    def _export_native_components(self, dict_out):
+        dict_out["native components"] = {}
+        duplicate_dict = self._get_duplicate_names()
+
+        def add_duplicate_dic_to_history(node_name, node, obj_name):
+            if node_name.startswith("Duplicate"):
+                node["Props"]["Duplicate Object"] = duplicate_dict[obj_name][node_name]
+            if node["Children"] != {}:
+                for node_name, node in node["Children"].items():
+                    add_duplicate_dic_to_history(node_name, node, obj_name)
+
+        for _, nc in self._app.native_components.items():
+            instance_name = nc.props["SubmodelDefinitionName"]
+            dict_out["native components"][instance_name] = {}
+            nc_props = dict(nc.props).copy()
+            nc_type = nc.props["NativeComponentDefinitionProvider"]["Type"]
+            dict_out["native components"][instance_name]["Type"] = nc_type
+            if (
+                nc_type == "PCB"
+                and nc_props["NativeComponentDefinitionProvider"]["DefnLink"]["Project"] == "This Project*"
+            ):
+                nc_props["NativeComponentDefinitionProvider"]["DefnLink"]["Project"] = self._app.project_file
+            dict_out["native components"][instance_name]["Properties"] = nc_props
+            dict_out["native components"][instance_name]["Instances"] = {}
+            for i, v in self._app.modeler.user_defined_components.items():
+                cs_name = None
+                if v.definition_name == instance_name:
+                    if "Target Coordinate System" in self._app.oeditor.GetChildObject(i).GetPropNames():
+                        cs_name = v.target_coordinate_system
+                    obj_history = v.history()
+                    if obj_history:
+                        obj_history = obj_history.jsonalize_tree()
+                        for node_name, node in obj_history.items():
+                            add_duplicate_dic_to_history(node_name, node, i)
+                    else:
+                        obj_history = None
+                    dict_out["native components"][instance_name]["Instances"][v.name] = {
+                        "CS": cs_name,
+                        "Operations": obj_history,
+                    }
+        if not self.options.export_coordinate_systems:  # pragma: no cover
+            self._export_coordinate_systems(dict_out)
+
+    @pyaedt_function_handler
+    def _update_native_components(self, native_name, native_dict):
+        def apply_operations_to_native_components(obj, operation_dict, native_dict):  # pragma: no cover
+            cache_cs = self._app.oeditor.GetActiveCoordinateSystem()
+            self._app.modeler.set_working_coordinate_system(operation_dict["Props"]["Coordinate System"])
+            new_objs = None
+            self._app.modeler.refresh_all_ids()
+            old_objs = list(self._app.modeler.user_defined_components.keys())
+            if operation_dict["Props"]["Command"] == "Move":
+                obj.move(
+                    [decompose_variable_value(operation_dict["Props"]["Move Vector"][2 * i + 1])[0] for i in range(3)]
+                )
+            elif operation_dict["Props"]["Command"] == "Rotate":
+                rotation = decompose_variable_value(operation_dict["Props"]["Angle"])
+                obj.rotate(operation_dict["Props"]["Axis"], angle=rotation[0], unit=rotation[1])
+            elif operation_dict["Props"]["Command"] == "Mirror":
+                obj.mirror(
+                    [
+                        decompose_variable_value(operation_dict["Props"]["Base Position"][2 * i + 1])[0]
+                        for i in range(3)
+                    ],
+                    [
+                        decompose_variable_value(operation_dict["Props"]["Normal Position"][2 * i + 1])[0]
+                        for i in range(3)
+                    ],
+                )
+            elif operation_dict["Props"]["Command"] == "DuplicateAlongLine":
+                new_objs = obj.duplicate_along_line(
+                    [decompose_variable_value(operation_dict["Props"]["Vector"][2 * i + 1])[0] for i in range(3)],
+                    nclones=operation_dict["Props"]["Total Number"],
+                    attach_object=operation_dict["Props"]["Attach To Original Object"],
+                )
+            elif operation_dict["Props"]["Command"] == "DuplicateAroundAxis":
+                rotation = decompose_variable_value(operation_dict["Props"]["Angle"])
+                new_objs = obj.duplicate_around_axis(
+                    operation_dict["Props"]["Axis"], angle=rotation[0], nclones=operation_dict["Props"]["Total Number"]
+                )
+            elif operation_dict["Props"]["Command"] == "DuplicateMirror":
+                new_objs = obj.duplicate_and_mirror(
+                    position=[
+                        decompose_variable_value(operation_dict["Props"]["Base Position"][2 * i + 1])[0]
+                        for i in range(3)
+                    ],
+                    vector=[
+                        decompose_variable_value(operation_dict["Props"]["Normal Position"][2 * i + 1])[0]
+                        for i in range(3)
+                    ],
+                )
+            else:  # pragma: no cover
+                raise "Operation not supported"
+            if new_objs:
+                new_objs = list(set(new_objs) - set(old_objs))
+                for new_obj in new_objs:
+                    if native_dict[new_obj]["Operations"]:
+                        for dup_obj in operation_dict["Props"]["Duplicate Object"]:
+                            for _, operation_dict in native_dict[dup_obj]["Operations"].items():
+                                apply_operations_to_native_components(
+                                    self._app.modeler.user_defined_components[new_obj], operation_dict, native_dict
+                                )
+            for _, operation_dict in operation_dict["Children"].items():
+                apply_operations_to_native_components(obj, operation_dict, native_dict)
+            self._app.modeler.set_working_coordinate_system(cache_cs)
+            return True
+
+        for _, instance_dict in native_dict["Instances"].items():
+            if instance_dict["CS"]:
+                nc_dict = copy.deepcopy(native_dict["Properties"])
+                nc_dict["TargetCS"] = instance_dict["CS"]
+                component3d_names = list(self._app.modeler.oeditor.Get3DComponentInstanceNames(native_name))
+                native = NativeComponentObject(self._app, native_dict["Type"], native_name, nc_dict)
+                prj_list = set(self._app.project_list)
+                definition_names = set(self._app.oeditor.Get3DComponentDefinitionNames())
+                instance_names = {
+                    def_name: set(self._app.oeditor.Get3DComponentInstanceNames(def_name))
+                    for def_name in definition_names
+                }
+                if not native.create():  # pragma: no cover
+                    return False
+                try:
+                    definition_names = list(set(self._app.oeditor.Get3DComponentDefinitionNames()) - definition_names)[
+                        0
+                    ]
+                    instance_names = list(self._app.oeditor.Get3DComponentInstanceNames(definition_names))[0]
+                except IndexError:
+                    definition_names = [
+                        def_name
+                        for def_name in definition_names
+                        if len(set(self._app.oeditor.Get3DComponentInstanceNames(def_name)) - instance_names[def_name])
+                        > 0
+                    ][0]
+                    instance_names = list(
+                        set(self._app.oeditor.Get3DComponentInstanceNames(definition_names))
+                        - instance_names[definition_names]
+                    )[0]
+                native.component_name = definition_names
+                native.name = instance_names
+                if nc_dict["NativeComponentDefinitionProvider"]["Type"] == "PCB" and nc_dict[
+                    "NativeComponentDefinitionProvider"
+                ]["DefnLink"]["Project"] not in [self._app.project_file or "This Project*"]:
+                    prj = list(set(self._app.project_list) - prj_list)[0]
+                    design = nc_dict["NativeComponentDefinitionProvider"]["DefnLink"]["Design"]
+                    app = get_pyaedt_app(prj, design)
+                    app.oproject.Close()
+                user_defined_component = UserDefinedComponent(
+                    self._app.modeler, instance_names, nc_dict["NativeComponentDefinitionProvider"], native_dict["Type"]
+                )
+                self._app.modeler.user_defined_components[instance_names] = user_defined_component
+                new_name = [
+                    i
+                    for i in list(
+                        self._app.modeler.oeditor.Get3DComponentInstanceNames(user_defined_component.definition_name)
+                    )
+                    if i not in component3d_names
+                ][0]
+                self._app.modeler.refresh_all_ids()
+                self._app.materials._load_from_project()
+                if native.component_name not in self._app.native_components:
+                    self._app._native_components.append(native)
+                if instance_dict.get("Operations", None):
+                    for _, operation_dict in instance_dict["Operations"].items():
+                        apply_operations_to_native_components(
+                            self._app.modeler.user_defined_components[new_name],
+                            operation_dict,
+                            native_dict["Instances"],
+                        )
+        return True
