@@ -10,6 +10,7 @@ import json
 import math
 import os
 import re
+import sys
 
 from pyaedt import is_ironpython
 from pyaedt import settings
@@ -24,12 +25,6 @@ from pyaedt.modules.Material import MatProperties
 from pyaedt.modules.Material import OrderedDict
 from pyaedt.modules.Material import SurfaceMaterial
 
-if not is_ironpython:
-    try:
-        import pandas as pd
-    except ImportError:
-        pd = None
-
 
 class Materials(object):
     """Contains the AEDT materials database and all methods for creating and editing materials.
@@ -66,7 +61,7 @@ class Materials(object):
         return len(self.material_keys)
 
     def __iter__(self):
-        return self.material_keys.itervalues()
+        return iter(self.material_keys.values()) if sys.version_info.major > 2 else self.material_keys.itervalues()
 
     def __getitem__(self, item):
         matobj = self.checkifmaterialexists(item)
@@ -779,8 +774,10 @@ class Materials(object):
         List of :class:`pyaedt.modules.Material.Material`
 
         """
-        if not pd:
-            self.logger.error("Pandas is needed. Please, install it first.")
+        try:  # pragma: no cover
+            import pandas as pd
+        except ImportError:
+            self.logger.error("Pandas is needed. Install it.")
             return False
         materials_added = []
         props = {}
@@ -809,7 +806,10 @@ class Materials(object):
                     and val[keys.index(prop)]
                     and not (isinstance(val[keys.index(prop)], float) and math.isnan(val[keys.index(prop)]))
                 ):
-                    props[prop] = val[keys.index(prop)]
+                    prop_value = val[keys.index(prop)]
+                    if prop_value.dtype == "int64":
+                        prop_value = prop_value.astype(float)
+                    props[prop] = prop_value
             new_material = Material(self, newname, props)
             new_material.update()
             self.material_keys[newname] = new_material
